pub struct Expiry {
pub manufacturer_date: Option<String>,
pub expiry_date: Option<String>,
pub expiry_after_duration: Option<Box<Duration>>,
}Fields
manufacturer_date: Option<String>Production, packaging or assembly date determined by the manufacturer. Its meaning is determined based on the trade item context.
expiry_date: Option<String>The date that determines the limit of consumption or use of a product. Its meaning is determined based on the trade item context.
expiry_after_duration: Option<Box<Duration>>Implementations